@@ -48,12 +48,10 @@ class WaifuAioClient:
             session: An aiohttp session.
             token: your API token.(its optional since you only use it for the private gallery endpoint /fav/)
             appname: the name of your app in the user agent (please use it its easyer to identify you in the logs).
-            maintenance_error: The error massage that will be raise if the API status code is a 502.
         """
         self.session=session
         self.token=token
         self.appname=appname
-        self.maintenance_error=maintenance_error
 
     async def __aenter__(self):
         return self
